@@ -33,7 +33,7 @@ PROCESSX_STATIC ssize_t processx_socket_write(processx_socket_t *pxsocket,
                                               void *buf,
                                               size_t nbyte);
 PROCESSX_STATIC int processx_socket_close(processx_socket_t *pxsocket);
-PROCESSX_STATIC const char* processx_socket_error_message();
+PROCESSX_STATIC const char* processx_socket_error_message(void);
 
 #ifdef __cplusplus
 }
